import { API_URL } from '$env/static/private';

import type { Handle, HandleFetch, HandleServerError } from '@sveltejs/kit';

import { COOKIES } from '$lib/constants';

export const handle: Handle = async ({ event, resolve }) => {
  const session = event.cookies.get(COOKIES.SESSION);

  if (!session) {
    event.locals.user = null;
    return resolve(event);
  }

  try {
    const res = await fetch(API_URL + '/player/', {
      headers: {
        Authorization: `Bearer ${session}`
      }
    });

    if (!res.ok) {
      event.locals.user = null;
      event.cookies.delete(COOKIES.SESSION, { path: '/' });
      return resolve(event);
    }

    const user = await res.json();
    event.locals.user = user;

    return resolve(event);
  } catch (error) {
    console.error(error);
    event.locals.user = null;
    event.cookies.delete(COOKIES.SESSION, { path: '/' });
    return resolve(event);
  }
};

export const handleFetch: HandleFetch = async ({ event, request, fetch }) => {
  const session = event.cookies.get(COOKIES.SESSION);

  if (!session) {
    return fetch(request);
  }

  const headers = {
    ...request.headers,
    Authorization: `Bearer ${session}`
  };

  request = new Request(request, { headers });

  return fetch(request);
};

export const handleError: HandleServerError = async ({ error, status }) => {
  const errorId = crypto.randomUUID();

  console.error(`Error ID: ${errorId} - Status: ${status} - ${error}`);

  return {
    message: 'Internal server error',
    status,
    errorId
  }
};
