import { API_URL } from "$env/static/private";
import { redirect, type Actions } from "@sveltejs/kit";
import type { PageServerLoad } from "./$types";

import { fail, superValidate } from "sveltekit-superforms";
import { zod } from "sveltekit-superforms/adapters";

import type { Puzzle } from "$lib/types";

import { formSchema } from "./schema";

export const load: PageServerLoad = async ({ locals, fetch, params: { id } }) => {
  if (!locals.user || !locals.user.email.endsWith('@peerat.dev')) redirect(302, '/login');

  const res = await fetch(`${API_URL}/admin/puzzle/${id}`);

  if (!res.ok) redirect(302, '/admin/puzzles');

  const puzzle: Puzzle = await res.json()

  const form = await superValidate(puzzle, zod(formSchema));

  return {
    puzzle,
    form,
  };
};

export const actions: Actions = {
  default: async ({ request, locals: { user }, fetch, params: { id } }) => {

    if (!user) return fail(401);

    if (!user.email.endsWith('@peerat.dev')) return fail(401);

    const form = await superValidate(request, zod(formSchema));

    if (!form.valid) {
      return fail(400, { form });
    }

    const res = await fetch(`${API_URL}/admin/puzzle/${id}`, {
      method: "PUT",
      body: JSON.stringify({
        name: form.data.name,
        content: form.data.content,
        soluce: form.data.soluce,
        scoreMax: parseInt(form.data.score_max),
        chapter: parseInt(form.data.chapter)
      })
    });

    if (!res.ok) {
      return fail(500);
    }

    return {
      form
    };
  }
};
