import { API_URL } from "$env/static/private";

import type { PageServerLoad } from "./$types";

import { redirect } from "@sveltejs/kit";

import type { Chapter } from "$lib/types";
import { handleRedirect } from "$lib/utils";

export const load: PageServerLoad = async ({ url, locals, fetch }) => {
  if (!locals.user) {
    redirect(302, handleRedirect("login", url));
  }

  let chapters: Chapter[] = [];

  try {
    const res = await fetch(API_URL + "/chapters");

    if (res.ok) {
      chapters = await res.json();
    }
  } catch (error) {
    console.error("Error fetching chapters", error);
  }

  chapters = chapters?.sort((a) => {
    return (a.start && a.end) ? -1 : 1;
  });

  return {
    title: 'Chapitres',
    
    chapters,
  };
};
