import { API_URL } from "$env/static/private";

import type { PageServerLoad } from "./$types";

import { redirect } from "@sveltejs/kit";

import type { Chapter } from "$lib/types";
import { handleRedirect } from "$lib/utils";

export const load: PageServerLoad = async ({ url, locals, fetch, params: { chapterId } }) => {
  if (!locals.user) {
    redirect(302, handleRedirect("login", url));
  }

  let chapter: Chapter | null = null;

  const res = await fetch(API_URL + "/chapter/" + chapterId);

  if (res.ok) {
    chapter = await res.json();
  }

  if (!chapter || !chapter.show && !(chapter.start && chapter.end)) {
    redirect(302, "/chapters");
  }

  chapter.puzzles = chapter.puzzles?.sort((a, b) => a.scoreMax - b.scoreMax);

  return {
    title: chapter.name,
    
    chapter,
  };
};
